==> albert_0.25.0.orig.tar.gz: albert-0.25.0/plugins/python/i18n/python_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ConfigWidget</name>
    <message>
        <source>The Python plugin makes the app extendable by Python modules. The built-in albert module exposes several functions and classes for use with Albert. See the &lt;a href=&quot;https://github.com/albertlauncher/python/blob/master/albert.pyi&quot;&gt;Python stub file&lt;/a&gt; for a detailed interface specification. The Python plugins are loaded from `&amp;lt;APPDATADIR&amp;gt;/python/plugins`.</source>
        <translation type="vanished">Das Python-Plugin ermöglicht die Erweiterung der App durch Python-Module. Das integrierte Albert-Modul stellt mehrere Funktionen und Klassen für die Verwendung mit Albert bereit. Siehe die &lt;a href=&quot;https://github.com/albertlauncher/python/blob/master/albert.pyi&quot;&gt;Python-Stub-Datei&lt;/a&gt; für eine detaillierte Schnittstellenspezifikation. Die Python-Plugins werden aus &amp;lt;APPDATADIR&amp;gt;/python/plugins geladen.</translation>
    </message>
    <message>
        <location filename="../src/configwidget.ui" line="29"/>
        <source>The Python plugin makes the app extendable by Python modules. The built-in albert module exposes several functions and classes for use with Albert. The Python plugins are loaded from `&amp;lt;APPDATADIR&amp;gt;/python/plugins`.</source>
        <translation>Das Python-Plugin ermöglicht die Erweiterung der App durch Python-Module. Das integrierte Albert-Modul stellt mehrere Funktionen und Klassen für die Verwendung mit Albert bereit. Die Python-Plugins werden aus `&amp;lt;APPDATADIR&amp;gt;/python/plugins` geladen.</translation>
    </message>
    <message>
        <location filename="../src/configwidget.ui" line="51"/>
        <source>Open user plugin dir</source>
        <translation>Benutzerplugin-Verzeichnis öffnen</translation>
    </message>
    <message>
        <location filename="../src/configwidget.ui" line="58"/>
        <source>Open stub file</source>
        <translation>Stub-Datei öffnen</translation>
    </message>
    <message>
        <location filename="../src/configwidget.ui" line="65"/>
        <source>Open site-packages</source>
        <translation>Site-packages öffnen</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <source>Failed getting dependency &apos;%1&apos;.</source>
        <translation type="vanished">Fehler beim Abrufen der Abhängigkeit &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../src/plugin.cpp" line="48"/>
        <source>Failed creating site-packages dir %1</source>
        <translation>Fehler beim Erstellen des &quot;site-packages&quot; Verzeichnis %1</translation>
    </message>
    <message>
        <location filename="../src/plugin.cpp" line="54"/>
        <source>Failed creating writeable plugin dir %1</source>
        <translation>Erstellung des beschreibbaren Plugin-Verzeichnisses %1 fehlgeschlagen</translation>
    </message>
</context>
<context>
    <name>PyPluginLoader</name>
    <message>
        <source>Some modules in the plugin &apos;%1&apos; were not found. Probably the plugin has dependencies which are not installed on this system.

Install dependencies into the Albert virtual environment?</source>
        <translation type="obsolete">Einige Module im Plugin &apos;%1&apos; wurden nicht gefunden. Wahrscheinlich hat das Plugin Abhängigkeiten, die auf diesem System nicht installiert sind.

Abhängigkeiten in die Albert-Umgebung installieren?</translation>
    </message>
    <message>
        <location filename="../src/pypluginloader.cpp" line="242"/>
        <source>Some modules in the plugin &apos;%1&apos; were not found.

Install dependencies into the virtual environment?</source>
        <translation>Einige Module im Plugin &apos;%1&apos; wurden nicht gefunden.

Abhängigkeiten in die virtuelle Umgebung installieren?</translation>
    </message>
    <message>
        <location filename="../src/pypluginloader.cpp" line="304"/>
        <source>No &apos;%1&apos; in $PATH.</source>
        <translation>&apos;%1&apos; nicht in $PATH.</translation>
    </message>
</context>
</TS>

==> albert_0.26.3.orig.tar.gz: albert-0.26.3/plugins/python/i18n/python_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ConfigWidget</name>
    <message>
        <source>The Python plugin makes the app extendable by Python modules. The built-in albert module exposes several functions and classes for use with Albert. See the &lt;a href=&quot;https://github.com/albertlauncher/python/blob/master/albert.pyi&quot;&gt;Python stub file&lt;/a&gt; for a detailed interface specification. The Python plugins are loaded from `&amp;lt;APPDATADIR&amp;gt;/python/plugins`.</source>
        <translation type="vanished">Das Python-Plugin ermöglicht die Erweiterung der App durch Python-Module. Das integrierte Albert-Modul stellt mehrere Funktionen und Klassen für die Verwendung mit Albert bereit. Siehe die &lt;a href=&quot;https://github.com/albertlauncher/python/blob/master/albert.pyi&quot;&gt;Python-Stub-Datei&lt;/a&gt; für eine detaillierte Schnittstellenspezifikation. Die Python-Plugins werden aus &amp;lt;APPDATADIR&amp;gt;/python/plugins geladen.</translation>
    </message>
    <message>
        <source>The Python plugin makes the app extendable by Python modules. The built-in albert module exposes several functions and classes for use with Albert. The Python plugins are loaded from `&amp;lt;APPDATADIR&amp;gt;/python/plugins`.</source>
        <translation>Das Python-Plugin ermöglicht die Erweiterung der App durch Python-Module. Das integrierte Albert-Modul stellt mehrere Funktionen und Klassen für die Verwendung mit Albert bereit. Die Python-Plugins werden aus `&amp;lt;APPDATADIR&amp;gt;/python/plugins` geladen.</translation>
    </message>
    <message>
        <source>Open user plugin dir</source>
        <translation>Benutzerplugin-Verzeichnis öffnen</translation>
    </message>
    <message>
        <source>Open stub file</source>
        <translation>Stub-Datei öffnen</translation>
    </message>
    <message>
        <source>Open site-packages</source>
        <translation>Site-packages öffnen</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <source>Failed getting dependency &apos;%1&apos;.</source>
        <translation type="vanished">Fehler beim Abrufen der Abhängigkeit &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Failed creating writeable plugin dir %1</source>
        <translation>Erstellung des beschreibbaren Plugin-Verzeichnisses %1 fehlgeschlagen</translation>
    </message>
    <message>
        <source>Failed initializing the interpreter: %1 %2</source>
        <translation>Initialisierung des Intrerpreters fehlgeschlagen: %1 %2</translation>
    </message>
    <message>
        <source>Failed initializing virtual environment. Exit code: %1.</source>
        <translation>Initialisierung der virtuellen Umgebung fehlgeschlagen. Rückgabewert: %1.</translation>
    </message>
    <message>
        <source>Some modules in the plugin &apos;%1&apos; were not found.

Install dependencies into the virtual environment?</source>
        <translation>Einige Module im Plugin &apos;%1&apos; wurden nicht gefunden.

Abhängigkeiten in die virtuelle Umgebung installieren?</translation>
    </message>
    <message>
        <source>No &apos;%1&apos; in $PATH.</source>
        <translation>Kein &apos;%1&apos; in $PATH.</translation>
    </message>
</context>
</TS>
